# 3y
# __init__.py
from beginnings import *
from colorama import init
from datetime import datetime as sj
from time import sleep as dd
from math import pi as pai1
from sys import exit as tc
from pdsystem import * #The moudle of Maker:神秘的·  ps:需要pip下载,在终端输入pip install pdsystem
pdios()
start=sj.now()



#圆柱部分
from __init__ import *
pai2='π' #下面要用到，提前放上来 
def part_yz():
    while True:
        r=input('请输入半径:')#半径输入
        try:
            r=eval(r)
        except (IOError,ValueError,TypeError,SyntaxError,EOFError,NameError):
            print('')
        except ZeroDivisionError:
            print('除数不能为0，emmm，2年级小孩都知道')
            print('请使用正确符号或正确数字')
        H=input('请输入高:')#高输入 
        try:
            H=eval(H)
        except (IOError,ValueError,TypeError,SyntaxError,EOFError,NameError):
            print('请使用正确符号或正确数字')
        except ZeroDivisionError:
            print('除数不能为0，emmm，2年级小孩都知道')
        print('【圆柱】')
        aboutpi()
        xxx=input('请输入(1,2,3,4,5)中的一个数字:')
        print(' ')
        try:
            xxx=int(xxx)
        except (IOError,ValueError,TypeError,SyntaxError,EOFError,NameError):
            print('请输入有效数字')
        except ZeroDivisionError:
            print('除数不能为0，emmm，2年级小孩都知道')
        if r<=0 or H<=0:
            print('虽然输入成功，但是为什么弹出选择模式，自己想想为什么')
            print('0.1秒后切换模式')
            dd(0.1)
            break
        print(' ')
        if xxx>5 or xxx<=0:
            end1=sj.now()-start
            print('即将\033[10;31m退出\033[0m,','本次使用时间:',end1,'\n程序将在5秒后关闭,谢谢使用')
            dd(5)
            tc('谢谢使用')
        elif xxx==5:
            print('-'*40)
            print('切换模式')
            print('0.1秒后切换模式')
            dd(0.1)
            break
        elif xxx==1:
            dw()
            sU=r*r*3.14#上圆s
            sD=sU*2#双圆s
            d=2*r  #直径
            C=d*3.14 #周长
            Sc=C*H #侧s
            S=sD+Sc #表s
            V=sU*H
            if r<=0 and H<=0 or (S or C or Sc or sD or sU or d)<=0 : #if重点检查区域
                print('请重新输入半径和高，因为其中一个小于0或者数太小了，就像0.0001这样的，所以停止运行了')
                print('请选择模式，再次尝试运行')
                dd(0.5)
                break
            elif r>0 and H>0:
                dw()
                print('======计算结果======')
                print('当半径=',r,'直径=',d,'高=',H,'时')
                print('\n一个圆的周长=','{:.7f}'.format(C))
                print('一个圆的面积=','{:.7f}'.format(sU))
                print('两个圆的面积=','{:.7f}'.format(sD))
                print('圆柱的侧面积=','{:.7f}'.format(Sc))
                print('圆柱的体积=','{:.7f}'.format(V))
                print('圆柱的表面积=','{:.7f}'.format(S))
            else:
                print('重新输入半径和高，无需关闭')
                print('如果下面没有弹出请输入半径和请输入高，请关闭后重新打开')
        elif xxx==2:
            sU=r*r*pai1#上圆s
            sD=sU*2#双圆s
            d=2*r  #直径
            C=d*pai1 #周长
            Sc=C*H #侧s
            S=sD+Sc #表s
            V=sU*H
            if r<=0 and H<=0 or (S or C or Sc or sD or sU or d)<=0 : #if重点检查区域
                print('请重新输入半径和高，因为其中一个小于0或者数太小了，就像0.0001这样的，所以停止运行了')
                print('请重新打开，再次尝试运行')
                dd(0.5)
                break
            elif r>0 and H>0:
                dw()
                print('=====计算结果=====')
                print('当半径=',r,'直径=',d,'高=',H,'时')
                print('\n一个圆的周长=','{:.7f}'.format(C))
                print('一个圆的面积=','{:.7f}'.format(sU))
                print('两个圆的面积=','{:.7f}'.format(sD))
                print('圆柱的侧面积=','{:.7f}'.format(Sc))
                print('圆柱的体积=','{:.7f}'.format(V))
                print('圆柱的表面积=','{:.7f}'.format(S))
            else:
                print('重新输入半径和高，无需关闭')
                print('如果下面没有弹出请输入半径和请输入高,请重新打开')
        elif xxx==3:
            sU=r*r#上圆s 
            sD=sU*2#双圆s 
            d=2*r  #直径
            C=d #周长
            Sc=C*H #侧s 
            S=sD+Sc #表s 
            V=sU*H
            if r<=0 and H<=0 or (S or C or Sc or sD or sU or d)<=0 : #if重点检查区域
                print('请重新输入半径和高，因为其中一个小于0或者数太小了，就像0.0001这样的，所以停止运行了')
                print('请重新打开，再次尝试()运行')
                dd(0.5)
                break
            elif r>0 and H>0:
                dw()
                print('=====计算结果=====')
                print('当半径=',r,'直径=',d,'高=',H,'时')
                print('\n一个圆的周长=','{:.7f}'.format(C),pai2)
                print('一个圆的面积=','{:.7f}'.format(sU),pai2)
                print('两个圆的面积=','{:.7f}'.format(sD),pai2)
                print('圆柱的侧面积=','{:.7f}'.format(Sc),pai2)
                print('圆柱的体积=','{:.7f}'.format(V),pai2)
                print('圆柱的表面积=','{:.7f}'.format(S),pai2)
            else:
                print('重新输入半径和高')
        elif xxx==4:
            defpi=input('(请输入你要自定义的π，但是不要小于3或大于等于3.2):')
            try:
                defpi=eval(defpi)
            except (IOError,ValueError,TypeError,SyntaxError,EOFError,NameError):
                print('请输入指定范围的数字')
            except ZeroDivisionError:
                print('除数不能为0，emmm，2年级小孩都知道')       
            if defpi<3 or defpi >3.2:
                    print('0.3秒后切换模式')
                    dd(0.3)
                    break
            if defpi >=3 and defpi <3.2:
                sU=r*r*defpi#上圆s
                sD=sU*2#双圆s
                d=2*r  #直径
                C=d*defpi #周长
                Sc=C*H #侧s
                S=sD+Sc #表s
                V=sU*H#体积
                if r<=0 and H<=0 or (S or C or Sc or sD or sU or d)<=0 : #if重点检查区域
                    print('请重新输入半径和高，因为其中一个小于0或者数太小了，就像0.0001这样的，所以停止运行了')
                    print('请重新打开，再次尝试运行')
                    dd(0.5)
                    break
                elif r>0 and H>0:
                    dw()
                    print('=====计算结果=====')
                    print('当半径=',r,'直径=',d,'高=',H,'时')
                    print('\n一个圆的周长=','{:.8f}'.format(C))
                    print('一个圆的面积=','{:.8f}'.format(sU))
                    print('两个圆的面积=','{:.8f}'.format(sD))
                    print('圆柱的侧面积=','{:.8f}'.format(Sc))
                    print('圆柱的体积=','{:.8f}'.format(V))
                    print('圆柱的表面积=','{:.8f}'.format(S))
                else:
                    print('重新输入半径和高，无需关闭')
                    print('如果下面没有弹出请输入半径和请输入高,请重新打开(运行)')
        else:
            end1=sj.now()-start
            print('即将\033[10;31m退出\033[0m,','本次使用时间:',end1,'\n程序将在5秒后关闭,谢谢使用')
            dd(5)
            tc('谢谢使用')


#圆
from __init__ import *
# 即将更新log:1把每个判断放到input下面2print ('{} '.format(j))3.过多的无效代码行
pai2='π' 
def part_y():
    while True:
        r=input('请输入圆的半径:')
        try:
            r=eval(r)
        except (IOError,ValueError,TypeError,SyntaxError,EOFError,NameError):
            print('请输入有效数字')
        except ZeroDivisionError:
            print('除数不能为0，emmm，2年级小孩都知道')
        if r<=0:
            print('\n2个问题，要不你输入的数太小（0.0001 0.001…），python一算结果就是0\n要不然就是r＜0，你见过r小于0的吗？\n1请重新输入选择模式使用')
            print('0.3秒后切换模式')
            dd(0.3)
            break
        print('【圆】')
        aboutpi()
        xxx=input('请输入(1,2,3,4,5)中的一个数字:')
        print(' ')
        try:
            xxx=int(xxx)
        except (IOError,ValueError,TypeError,SyntaxError,EOFError,NameError):
            print('请输入指定范围的整数')
            print('退出…1s后切换模式')
            dd(1)
            break
        except ZeroDivisionError:
            print('除数不能为0，emmm，2年级小孩都知道')
        if xxx>5 or xxx<=0:
            end1=sj.now()-start
            print('即将\033[10;31m退出\033[0m,','本次使用时间:',end1,'\n程序将在3秒后关闭,谢谢使用')
            dd(3)
            tc('谢谢使用')
        elif xxx==5:
            print('-'*40)
            print('0.3秒后切换模式')
            dd(0.3)
            break
        elif xxx==1:
            if r<=0:
                print('\n2个问题，要不你输入的数太小（0.0001 0.001…），python一算结果就是0\n要不然就是r＜0，你见过r小于0的吗？\n1请重新输入选择模式使用')
                print('0.3秒后切换模式')
                dd(0.3)       
                break
            d=2*r #直径
            ra=r**2
            s=3.14*ra#面积
            c=3.14*d#周长
            dw()
            print('======计算结果======')
            print('当半径=',r,'直径=',d,'时')
            print('周长=','{:.6f}'.format(c))
            print('面积=','{:.6f}'.format(s))
        elif xxx==2:#π为pai1
            if r<=0:
                print('\n2个问题，要不你输入的数太小（0.0001 0.001…），python一算结果就是0\n要不然就是r＜0，你见过r小于0的吗？\n请重新输入选择模式使用')
                print('0.3秒后切换模式')
                dd(0.3)
                break   
            d=2*r #直径
            ra=r**2
            s=pai1*ra#面积
            c=pai1*d
            dw()
            print('======计算结果======')
            print('当半径=',r,'直径=',d,'时')
            print('周长=','{:.8f}'.format(c))
            print('面积=','{:.8f}'.format(s))
        elif xxx==3:#pai1为p
            if r<=0:
                print('2个问题，要不你输入的数太小（0.0001 0.001…），python一算结果就是0\n要不然就是r＜0，你见过r小于0的吗？\n请重新选择模式后运行')
                print('0.3秒后切换模式')
                dd(0.3)
                break
            d=2*r #直径
            ra=r**2
        #精确到第9位
            s=ra#面积
            c=r*2 #周长
            dw()
            print('======计算结果======')
            print('当半径=',r,'直径=',d,'时')
            print('周长=','{:.8f}'.format(c),pai2)
            print('面积=','{:.8f}'.format(s),pai2)
        elif xxx==4:
            defpi=input('(请输入你要自定义的π，但是不要小于3或大于等于3.2):')
            try:
                defpi=eval(defpi)
            except (ValueError,TypeError,IOError):
                print('请输入指定范围的数字')
            except ZeroDivisionError:
                print('除数不能为0，emmm，2年级小孩都知道')
            if defpi<3 or defpi >3.2:
                    end=sj.now()-start
                    print('本次使用时间:',end)
                    print('拜拜了您嘞，自己想想为什么,别生气哈,想明白后再用,5秒钟后关闭')
                    dd(5)
                    tc('谢谢使用')
            if defpi >=3 and defpi <3.2:
                if r<=0:
                    print('2个问题，要不你输入的数太小（0.0001 0.001…），python一算结果就是0\n要不然就是r＜0，你见过r小于0的吗？\n请重新选择该模式使用')
                    print('0.3秒后切换模式')
                    dd(0.3)
                    break
                d=2*r #直径
                ra=r**2
                s=defpi*ra#面积
                c=defpi*d
                dw()
                print('======计算结果======')
                print('当半径=',r,'直径=',d,'时')
                print('周长=','{:.8f}'.format(c))
                print('面积=','{:.8f}'.format(s))
        else:
            end1=sj.now()-start
            print('即将\033[10;31m退出\033[0m,','本次使用时间:',end1,'\n程序将在5秒后关闭,谢谢使用')
            dd(5)
            tc('谢谢使用')


from setuptools import setup, find_packages
__author__ = '神秘的·'
__date__ = '2020/7/17'
import codecs,os
def read(fname):
    '''
    定义read()，用来读取目录下的长描述
    我们一般将README文件中的内容读取出来叫做长描述，这个会在pypi中你的包的页面展现出来
    你也可以不用此办法，直接手动写内容
    pypi上支持.rst格式的文件，暂时不支持md格式；rst格式的文件在pypi上会自动转化为html形式显示在你的包的信息页面上
    '''
    return codecs.open(os.path.join(os.path.dirname(__file__),fname)).read()

setup(
    name='3y', # 名称
    py_modules=['__main__','beginnings','y','yh','yz','log','__init__'],
    version='2.6.2',
    description='三圆计算器,cmd或命令行 python -m main 命令开始运行', # 简单描述
#    long_description='MADE IN CHINE,THE PROJUCT MAKER IS CHINESE\npython方便你我他现在免费推出3圆(圆环圆圆柱)计算器，欢迎下载使用\n使用方法:运用cd命令或其他方式运行main.py\n请自觉观看README.md文件', 
    long_description=read('README.rst'),
    classifiers=[
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Intended Audience :: Developers',
    'Operating System :: OS Independent',
],
    keywords='3y', # 关键字
    author='神秘的·', # 作者
    author_email='3046479366@qq.com', # 邮箱
    url='', # 包含包的项目地址
    license='MIT', # 授权方式
    packages=find_packages(), # 包列表
    install_requires=['pdsystem','beginnings'],
    include_package_data=True,
    zip_safe=True,
)